@@ -60,17 +60,22 @@ AUTOLOAD
     goto &$sub
 }
 
+# stub destroy is necessary to dodge AUTOLOAD for
+# unused objects.
+
 DESTROY {}
 
 # keep require happy
+
 1
 
 __END__
 
 =head1 NAME
 
-Object::Trampoline - delay object construction until a method 
-is actually dispatched.
+Object::Trampoline - delay object construction until
+a method is actually dispatched, simplifies runtime definition
+of handler classes.
 
 =head1 SYNOPSIS
 
@@ -79,16 +84,16 @@ is actually dispatched.
     # the required object is in Expensive::Class and
     # has a constructor of "frobnicate".
 
-    my $obj = Object::Trampoline->frobnicate( 'Expensive::Class', @args );
+    my $dbh = Object::Trampoline->connect( 'DBI', @args );
 
     # after that just use the object as-is and it'll
     # transform itself into whatever you asked for when
     # the first real method call is made using it.
 
-    my $sth = $obj->foobar( @more_args );
+    my $sth = $dbh->prepare( 'select foo from bar' );
 
-    # specify the package and args from a config file or
-    # via inherited data.
+    # or specify the package and args from
+    # a config file or via inherited data.
 
     my %config = Config->read( $config_file_path );
 
@@ -97,24 +102,25 @@ is actually dispatched.
 
     my $handle = Object::Trampoline->$const( $class, $argz );
 
-    # at this point ref $handle eq 'Object::Trampoline::Bounce'
+    # at this point ref $handle is 'Object::Trampoline::Bounce'
 
-    $handle->do_something( @argz );
+    $handle->frobnicate( @argz );
 
-    # at this point ref $handle eq $class
+    # at this point ref $handle is $class
 
 =head1 DESCRIPTION
 
 There are times when constructing an object is expensive
-or has to be delayed -- heavily forked apache servers
-are one example.  This module creates a "trampoline"
-object: when called it replaces the object you have with
-the object you want. The module itself consists only
-of two AUTOLOADS: one with captures the constructor call,
-the other the first method call. The first class blesses
-a closure which creates the necessary object into the
-second class, which replces $_[0] with a new object and
-re-dispatches the call into the proper class.
+or has to be delayed -- database handles in heavily forked
+apache servers are one example.  This module creates
+a "trampoline" object: when called it replaces the object
+you have with the object you want. The module itself
+consists only of two AUTOLOADS: one with captures the
+constructor call, the other the first method call. The
+first class blesses a closure which creates the necessary
+object into the second class, which replces $_[0] with
+a new object and re-dispatches the call into the proper
+class.
 
 Using an autoload as the constructor allows Object::Trampoline
 to use whatever constructor name the "real" class uses
@@ -132,7 +138,9 @@ For example:
 
 becomes
 
-    my $dbh = Object::Trampoline( 'DBI', 'dbi:Foo:', $user, $pass, $conf );
+    my $dbh = Object::Trampoline->connect( 'DBI', 'dbi:Foo:', $user, $pass, $conf );
+
+eventually follwed by some use of the $dbh:
 
     # at this point $dbh is an Object::Trampline
 
@@ -157,7 +165,7 @@ to Object::Trampoline can be determined at runtime:
 
     ...
 
-    my $mailer = Object::Trampoline( $mailclass, @const_argz );
+    my $mailer = Object::Trampoline->construct( $mailclass, @const_argz );
 
     ...
 
@@ -165,10 +173,12 @@ to Object::Trampoline can be determined at runtime:
 
     $mailer->send( %message );
 
-This allows the actual class doing the deed to be set
-at runtime via command line or config file. The same thing
-can be done using "$mailclass->construct( @const_argz )"
-but then the construction will not be delayed.
+This can be handy when the constructor arguments themselvese
+are expensive to arrive at but the handler object must be 
+defined in advance. This allows $mailer to be defined as
+something even if the constructor arguments are not 
+available (or the construced class require-ed) yet.
+
 
 =head1 KNOWN BUGS
 
@@ -188,3 +198,4 @@ is really used.
 =head1 AUTHOR
 
 Steven Lembark <lembark@wrkhors.com>
+
